@@ -28,8 +28,11 @@ generate.pop.N <- function(population.description, region.obj){
       if(nrow(grid.locations) < N[strat]){
         warning(paste("DSsim is unable to generate the requested population size for strata ", strat, ". We recommend you check the spacing of the density grid is appropriate, it may need reducing. Population size requested = ", N[strat], ", Population size generated = ", nrow(grid.locations),".", sep = ""), call. = FALSE)
       }else{
-        grid.locations <- grid.locations[1:N[strat],]  
+        grid.locations <- grid.locations[1:N[strat],]
       }
+      # Add strata ID
+      grid.locations$strata <- rep(strat, nrow(grid.locations))
+      # Accumulate all location
       if(first){
         all.grid.locations <- grid.locations
         first <- FALSE
